Documentation
¶
Index ¶
Constants ¶
const ( // OriginalOfficialDownloadPageURL Golang official site download page URL OriginalOfficialDownloadPageURL = "https://golang.org/dl/" // OfficialDownloadPageURL Golang official site download page URL OfficialDownloadPageURL = "https://go.dev/dl/" // CNDownloadPageURL China mirror site download page URL CNDownloadPageURL = "https://golang.google.cn/dl/" )
official collector
const ( // AliYunDownloadPageURL Alibaba cloud mirror site URL AliYunDownloadPageURL = "https://mirrors.aliyun.com/golang/" // HUSTDownloadPageURL Huazhong University of Science and Technology mirror site URL HUSTDownloadPageURL = "https://mirrors.hust.edu.cn/golang/" // NJUDownloadPageURL Nanjing University mirror site URL NJUDownloadPageURL = "https://mirrors.nju.edu.cn/golang/" )
Nginx fancyindex collector
const (
// USTCDownloadPageURL University of Science and Technology of China mirror site URL
USTCDownloadPageURL = "https://mirrors.ustc.edu.cn/golang/"
)
Nginx autoindex collector
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Collector ¶
type Collector interface {
// Name Collector name
Name() string
// StableVersions Return all stable versions
StableVersions() (items []*version.Version, err error)
// UnstableVersions Return all stable versions
UnstableVersions() (items []*version.Version, err error)
// ArchivedVersions Return all archived versions
ArchivedVersions() (items []*version.Version, err error)
// AllVersions Return all versions
AllVersions() (items []*version.Version, err error)
}
Collector Version information collector
func NewCollector ¶
NewCollector Returns the first available collector instance official|https://go.dev/dl/,fancyindex|https://mirrors.aliyun.com/golang/,autoindex|https://mirrors.ustc.edu.cn/golang/
Click to show internal directories.
Click to hide internal directories.